****************
Google Analytics
****************

To know what it’s going on on a page without damage privacy. Google analytics (GA) will not be used for chat page. 
Moreover GA will collect events:

* Create new chat
* Join to the chat
